Method: Infusionsoft::Client::Affiliate#affiliate_clawbacks

Defined in:
lib/infusionsoft/client/affiliate.rb

#affiliate_clawbacks(affiliate_id, start_date, end_date) ⇒ Array

Used when you need to retrieve all clawed back commissions for a particular affiliate.

Parameters:

  • affiliate_id (Integer)

Returns:

  • (Array)

    all claw backs for the given affiliate that have occurred within the date range specified



17
18
19
# File 'lib/infusionsoft/client/affiliate.rb', line 17

def affiliate_clawbacks(affiliate_id, start_date, end_date)
  response = xmlrpc('APIAffiliateService.affClawbacks', affiliate_id, start_date, end_date)
end